@@ -1,11 +1,11 @@
 """
-    test_basic
-    ~~~~~~~~~~~
+test_basic
+~~~~~~~~~~~
 
-    Test common functionality
+Test common functionality
 
-    :copyright: (c) 2019-2024 by J. Christopher Wagner (jwag).
-    :license: MIT, see LICENSE for more details.
+:copyright: (c) 2019-2024 by J. Christopher Wagner (jwag).
+:license: MIT, see LICENSE for more details.
 """
 
 import base64
@@ -28,7 +28,7 @@ from tests.test_utils import (
     check_location,
     get_auth_token_version_3x,
     get_form_action,
-    get_form_input,
+    get_form_input_value,
     hash_password,
     init_app_with_options,
     is_authenticated,
@@ -157,6 +157,8 @@ def test_authenticate_with_subdomain_next(app, client, get_message):
 
 @pytest.mark.settings(subdomain="auth")
 def test_authenticate_with_root_domain_next(app, client, get_message):
+    # As of Flask 3.1 this must be explicitly set.
+    app.subdomain_matching = True
     app.config["SERVER_NAME"] = "lp.com"
     app.config["SECURITY_REDIRECT_ALLOW_SUBDOMAINS"] = True
     data = dict(email="matt@lp.com", password="password")
@@ -226,7 +228,7 @@ def test_authenticate_case_insensitive_email(app, client):
 def test_authenticate_with_invalid_input(client, get_message):
     response = client.post(
         "/login",
-        json=dict(password="password"),
+        json=dict(password="password", email="mememe@test.com"),
         headers={"Content-Type": "application/json"},
     )
     assert get_message("USER_DOES_NOT_EXIST") in response.data
@@ -897,7 +899,7 @@ def test_http_auth_csrf(client, get_message):
 
     # grab a csrf_token
     response = client.get("/login")
-    csrf_token = get_form_input(response, "csrf_token")
+    csrf_token = get_form_input_value(response, "csrf_token")
     headers["X-CSRF-Token"] = csrf_token
     response = client.post(
         "/http",
@@ -1171,6 +1173,9 @@ def test_change_token_uniquifier(app):
     token = response.json["response"]["user"]["authentication_token"]
     verify_token(client_nc, token)
 
+    with app.app_context():
+        db.engine.dispose()
+
 
 def test_null_token_uniquifier(app):
     pytest.importorskip("sqlalchemy")
@@ -1212,11 +1217,14 @@ def test_null_token_uniquifier(app):
         ds.put(user)
         ds.commit()
 
-        client_nc = app.test_client(use_cookies=False)
+    client_nc = app.test_client(use_cookies=False)
 
-        response = json_authenticate(client_nc)
-        token = response.json["response"]["user"]["authentication_token"]
-        verify_token(client_nc, token)
+    response = json_authenticate(client_nc)
+    token = response.json["response"]["user"]["authentication_token"]
+    verify_token(client_nc, token)
+
+    with app.app_context():
+        db.engine.dispose()
 
 
 def test_token_query(app, client_nc):
